'use strict';

var _store = require('../store');

var _confirm = require('../confirm');

var _confirm2 = _interopRequireDefault(_confirm);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var init = _store.store.getState();

beforeEach(function () {
  _store.store.setState(init);
});

test('defaults', function () {
  expect(_store.store.getState()).toEqual({
    active: false,
    text: '',
    options: {},
    deferred: null
  });
});

test('actions.open: should work', function () {
  (0, _confirm2.default)({ text: 'hey' });

  var state = _store.store.getState();

  expect(state).toEqual({
    active: true,
    text: 'hey',
    options: {},
    deferred: { resolve: state.deferred.resolve, reject: state.deferred.reject }
  });
});

test('actions.open: should throw when already active', function () {
  (0, _confirm2.default)({ text: 'hey' });

  expect(function () {
    _store.actions.open(_store.store.getState(), { text: 'hey' });
  }).toThrow('Only a single confirm can be active at a time.');
});

test('actions.open: transform string text', function () {
  (0, _confirm2.default)('hey');

  var state = _store.store.getState();

  expect(state).toEqual({
    active: true,
    text: 'hey',
    options: {},
    deferred: { resolve: state.deferred.resolve, reject: state.deferred.reject }
  });
});

test.only('actions.open: map all keys except text to options', function () {
  (0, _confirm2.default)({ text: 'hey', title: 'sup', actions: ['wat'] });

  var state = _store.store.getState();

  expect(state.options).toEqual({ title: 'sup', actions: ['wat'] });
});

test('actions.open: should return promise', function () {
  var result = (0, _confirm2.default)({ text: 'hey' });
  expect(result.then).not.toEqual(null);
});

test('actions.dismiss: should noop when inactive', function () {
  _store.store.action(_store.actions.dismiss)();
  expect(_store.store.getState()).toEqual(init);
});

test('actions.dismiss: should work', function () {
  var promise = (0, _confirm2.default)({ text: 'hi' }).then(null, function (res) {
    expect(_store.store.getState()).toEqual(init);
  });

  _store.store.action(_store.actions.dismiss)();

  return promise;
}, 1000);

test('actions.proceed: should noop when inactive', function () {
  _store.store.action(_store.actions.proceed)();
  expect(_store.store.getState()).toEqual(init);
});

test('actions.proceed: should work', function () {
  var promise = (0, _confirm2.default)({ text: 'hi' }).then(function (res) {
    expect(_store.store.getState()).toEqual(init);
  });

  _store.store.action(_store.actions.proceed)();

  return promise;
}, 1000);