'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.actions = exports.store = undefined;

var _unistore = require('./unistore');

var _unistore2 = _interopRequireDefault(_unistore);

var _omit = require('./omit');

var _omit2 = _interopRequireDefault(_omit);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var store = (0, _unistore2.default)({
  active: false,
  text: '',
  options: {},
  deferred: null
});

var actions = {
  open: function open(state, opts) {
    if (state.active) {
      throw new Error('Only a single confirm can be active at a time.');
    }

    // opts(str)
    if (typeof opts === 'string') {
      var text = opts;
      opts = { text: text };
    }

    // opts ({ text, actions, etc })
    // Put all other stuff inside `options`
    opts.options = (0, _omit2.default)(opts, ['text']);

    return new Promise(function (resolve, reject) {
      store.setState({
        active: true,
        text: opts.text,
        options: opts.options,
        deferred: { resolve: resolve, reject: reject }
      });
    });
  },
  proceed: function proceed(state) {
    if (!state.active) {
      return;
    }

    state.deferred.resolve();

    return {
      active: false,
      text: '',
      options: {},
      deferred: null
    };
  },
  dismiss: function dismiss(state) {
    if (!state.active) {
      return;
    }

    state.deferred.reject();

    return {
      active: false,
      text: '',
      options: {},
      deferred: null
    };
  }
};

exports.store = store;
exports.actions = actions;